import { IConstruct } from '@aws-cdk/core';
import { NagPack } from '../common';
/**
 * Check for NIST 800-53 compliance.
 *
 * Based on the NIST 800-53 AWS operational best practices: https://docs.aws.amazon.com/config/latest/developerguide/operational-best-practices-for-nist-800-53_rev_4.html
 *
 * @stability stable
 */
export declare class NIST80053Checks extends NagPack {
    /**
     * All aspects can visit an IConstruct.
     *
     * @stability stable
     */
    visit(node: IConstruct): void;
    /**
     * Check API Gateway Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkAPIGW;
    /**
     * Check Auto Scaling Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkAutoScaling;
    /**
     * Check DMS Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkDMS;
    /**
     * Check CloudTrail Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkCloudTrail;
    /**
     * Check CodeBuild Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkCodeBuild;
    /**
     * CheckDynamoDB Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkDynamoDB;
    /**
     * Check EC2 Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkEC2;
    /**
     * Check EFS Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkEFS;
    /**
     * Check Elasticache Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkElastiCache;
    /**
     * Check Elasticsearch Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkElasticsearch;
    /**
     * Check Elastic Load Balancer Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkELB;
    /**
     * Check EMR Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkEMR;
    /**
     * Check IAM Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkIAM;
    /**
     * Check Lambda Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkLambda;
    /**
     * Check Amazon RDS Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkRDS;
    /**
     * Check Redshift Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkRedshift;
    /**
     * Check Amazon S3 Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkS3;
    /**
     * Check SageMaker Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkSageMaker;
    /**
     * Check Amazon SNS Resources
     * @param node the IConstruct to evaluate
     * @param ignores list of ignores for the resource
     */
    private checkSNS;
}
